import * as AWS from 'aws-sdk';
import { TypeInfo } from './type-info';
export interface ICloudFormationClient {
    listTypes(input: AWS.CloudFormation.ListTypesInput): Promise<AWS.CloudFormation.ListTypesOutput>;
    describeType(input: AWS.CloudFormation.DescribeTypeInput): Promise<AWS.CloudFormation.DescribeTypeOutput>;
}
export interface DescribeResourceTypeOptions {
    /**
     * Query with VISIBILITY=PRIVATE which means you can only import types that
     * are registred in your account (either types that you created or public
     * types that you activated).
     */
    readonly private?: boolean;
    /**
     * A client that performs calls to CloudFormation. You can provide a mock here
     * for testing.
     *
     * @default - A real CloudFormation client
     */
    readonly client?: ICloudFormationClient;
}
/**
 * Calls the CFN resource type registry to fetch the type definition
 *
 * @param name the name or unique prefix of the resource type
 * @returns the type definition
 */
export declare function describeResourceType(name: string, options?: DescribeResourceTypeOptions): Promise<TypeInfo>;
